function [ shape ] = findShape( filename )

% Read in the original image
pout = imread(filename);
K = rgb2gray(pout);

% Create a black and white image of the target
bw = im2bw(K, graythresh(K));
bw2 = imfill(bw,'holes');

% Close any gaps left by the letter, this number will scale with the size
% of the picture being processed
se = strel('disk',2);
bw2 = imclose(bw2,se);

signature = bw2sig(bw2, pout);

%Normalize the signature
maxi = max(signature);
signature(:,2) = signature(:,2)./maxi(2);

%Filter the data to smooth it
windowSize = 4;
signature(:,2) = polarFilter(signature(:,2),windowSize);

for w=1:(length(signature)-1)
    Dsignature(w) = signature(w,2)-signature(w+1,2);
end
Dsignature(length(signature)) = signature(length(signature),2)-signature(1,2);
%plot(Dsignature);
%figure;
windowSize = 4;
Dsignature = polarFilter(Dsignature,windowSize);
%plot(Dsignature);

[Lmin Lmax] = findzeroes(Dsignature, 6);

% Create a list of just the max points
for p=1:length(Lmax)
   maxPts(p,:) = signature(Lmax(p),:); 
end

% Create a list of just the min points
for p=1:length(Lmin)
   minPts(p,:) = signature(Lmin(p),:); 
end

%based just on the critical points, identify the shape
shape = pts2shape(maxPts, minPts, signature)

%{
%Graph the results
figure;
h = polar(signature(windowSize:length(signature),1),signature(windowSize:length(signature),2));

hold(gca,'on');
hold(imgca,'on');

% Add first point to end of list to close the shape
maxPts(length(Lmax)+1,:) = signature(Lmax(1),:); 
minPts(length(Lmin)+1,:) = signature(Lmin(1),:); 

% Draw the shapes
polar(gca,maxPts(:,1),maxPts(:,2),'--r');
polar(gca,minPts(:,1),minPts(:,2),'--g');

for p=1:length(Lmin)
    plot(imgca,signature(Lmin(p),4),signature(Lmin(p),3), 'r*');
    polar(gca,signature(Lmin(p),1),signature(Lmin(p),2),'g*');
end
for p=1:length(Lmax)
    polar(gca,signature(Lmax(p),1),signature(Lmax(p),2),'r*');
    plot(imgca,signature(Lmax(p),4),signature(Lmax(p),3), 'r*');
end
hold(gca,'off');
hold(imgca,'off');
%saveas(h,'shapeFile.jpg');
%}
end

